import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { MongooseModule } from '@nestjs/mongoose';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { IndustryChangeApplicationModule } from './industry-change-application/industry-change-application.module';
import { ResidentModule } from './resident/resident.module';
import { CommandModule } from 'nestjs-command';

@Module({
  imports: [
    CommandModule,
    ConfigModule.forRoot({}),
    MongooseModule.forRootAsync({
      imports: [ConfigModule],
      useFactory: async (configService: ConfigService) => ({
        uri: configService.get<string>('MONGODB_URI'),
      }),
      inject: [ConfigService],
    }),
    ResidentModule,
    IndustryChangeApplicationModule,
  ],
  controllers: [AppController],
  providers: [AppService],
})
export class AppModule {}
